@@ -3,6 +3,7 @@ Evrything Docs
 https://dashboard.evrythng.com/documentation/api/thngs
 """
 from evrythng import assertions, utils
+from evrythng.entities.actions import field_specs as action_field_specs
 
 
 field_specs = {
@@ -24,6 +25,20 @@ field_specs = {
 }
 
 
+def create_thng_action(type_, thng, timestamp=None, identifiers=None, location=None,
+                       locationSource=None, context=None, customFields=None, api_key=None):
+    """Create an Action for a Thng"""
+    kwargs = locals()
+    kwargs['type'] = kwargs['type_']
+    del kwargs['type_']
+    api_key = kwargs.pop('api_key', None)
+    assertions.validate_field_specs(kwargs, action_field_specs)
+
+    url = '/thngs/{}/actions/{}'.format(thng, type_)
+
+    return utils.request('POST', url, data=kwargs, api_key=api_key)
+
+
 def create_thng(name, description=None, product=None, location=None,
                 identifiers=None, properties=None, tags=None, collections=None,
                 customFields=None, api_key=None):
